@@ -73,8 +73,7 @@ class ETDataset(_Dataset):
     def __len__(self):
         return len(self.indices)
 
-    @property
-    def transforms(self):
+    def transforms(self, **kw):
         return None
 
     def add(self, files, debug=True, **kw):
